==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/mariadb/v20170312/models/DescribeFlowRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.mariadb.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeFlowRequest  extends AbstractModel{

    /**
    * 异步请求接口返回的任务流程号。
    */
    @SerializedName("FlowId")
    @Expose
    private Integer FlowId;

    /**
     * 获取异步请求接口返回的任务流程号。
     * @return FlowId 异步请求接口返回的任务流程号。
     */
    public Integer getFlowId() {
        return this.FlowId;
    }

    /**
     * 设置异步请求接口返回的任务流程号。
     * @param FlowId 异步请求接口返回的任务流程号。
     */
    public void setFlowId(Integer FlowId) {
        this.FlowId = FlowId;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "FlowId", this.FlowId);

    }
}

==> tencentcloud-sdk-java-3.1.72-sources.jar: com/tencentcloudapi/mariadb/v20170312/models/DescribeFlowRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.mariadb.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeFlowRequest extends AbstractModel{

    /**
    * 异步请求接口返回的任务流程号。
    */
    @SerializedName("FlowId")
    @Expose
    private Long FlowId;

    /**
     * Get 异步请求接口返回的任务流程号。 
     * @return FlowId 异步请求接口返回的任务流程号。
     */
    public Long getFlowId() {
        return this.FlowId;
    }

    /**
     * Set 异步请求接口返回的任务流程号。
     * @param FlowId 异步请求接口返回的任务流程号。
     */
    public void setFlowId(Long FlowId) {
        this.FlowId = FlowId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "FlowId", this.FlowId);

    }
}
